@@ -126,11 +126,11 @@ static const char *get_tls_config(void)
 static int chown_cb(const char *filename, const struct stat *st, int flag)
 {
         int ret;
-        uid_t uid;
-        gid_t gid;
+        prelude_uid_t uid;
+        prelude_gid_t gid;
 
-        uid = uid_set ? prelude_client_profile_get_uid(profile) : -1;
-        gid = gid_set ? prelude_client_profile_get_gid(profile) : -1;
+        uid = uid_set ? prelude_client_profile_get_uid(profile) : (prelude_uid_t) -1;
+        gid = gid_set ? prelude_client_profile_get_gid(profile) : (prelude_gid_t) -1;
 
         ret = chown(filename, uid, gid);
         if ( ret < 0 )
@@ -404,7 +404,7 @@ static void print_send_help(void)
 #if !((defined _WIN32 || defined __WIN32__) && !defined __CYGWIN__)
 static int set_uid(prelude_option_t *opt, const char *optarg, prelude_string_t *err, void *context)
 {
-        uid_t uid;
+        prelude_uid_t uid;
         const char *p;
         struct passwd *pw;
 
@@ -432,7 +432,7 @@ static int set_uid(prelude_option_t *opt, const char *optarg, prelude_string_t *
 
 static int set_gid(prelude_option_t *opt, const char *optarg, prelude_string_t *err, void *context)
 {
-        uid_t gid;
+        prelude_gid_t gid;
         const char *p;
         struct group *grp;
 
@@ -841,6 +841,44 @@ static int anon_check_passwd(prelude_io_t *fd, char *passwd)
 }
 
 
+static inline gnutls_transport_ptr fd_to_ptr(int fd)
+{
+        union {
+                gnutls_transport_ptr ptr;
+                int fd;
+        } data;
+
+        data.fd = fd;
+
+        return data.ptr;
+}
+
+
+static inline int ptr_to_fd(gnutls_transport_ptr ptr)
+{
+        union {
+                gnutls_transport_ptr ptr;
+                int fd;
+        } data;
+
+        data.ptr = ptr;
+
+        return data.fd;
+}
+
+
+static ssize_t tls_pull(gnutls_transport_ptr fd, void *buf, size_t count)
+{
+        return read(ptr_to_fd(fd), buf, count);
+}
+
+
+
+static ssize_t tls_push(gnutls_transport_ptr fd, const void *buf, size_t count)
+{
+        return write(ptr_to_fd(fd), buf, count);
+}
+
 
 static gnutls_session new_tls_session(int sock, char *passwd)
 {
@@ -856,11 +894,6 @@ static gnutls_session new_tls_session(int sock, char *passwd)
                 0
         };
 
-        union {
-                int fd;
-                void *ptr;
-        } data;
-
         gnutls_init(&session, GNUTLS_CLIENT);
         gnutls_set_default_priority(session);
         gnutls_kx_set_priority(session, kx_priority);
@@ -877,8 +910,9 @@ static gnutls_session new_tls_session(int sock, char *passwd)
         gnutls_anon_allocate_client_credentials(&anoncred);
         gnutls_credentials_set(session, GNUTLS_CRD_ANON, anoncred);
 
-        data.fd = sock;
-        gnutls_transport_set_ptr(session, data.ptr);
+        gnutls_transport_set_ptr(session, fd_to_ptr(sock));
+        gnutls_transport_set_pull_function(session, tls_pull);
+        gnutls_transport_set_push_function(session, tls_push);
 
         ret = gnutls_handshake(session);
         if ( ret < 0 ) {
@@ -1047,8 +1081,11 @@ static int ask_one_shot_password(char **buf, const char *ask, ...)
 
                 snprintf(str, sizeof(str), "Confirm %s: ", askbuf);
                 pass2 = getpass(str);
-                if ( ! pass2 )
+                if ( ! pass2 ) {
+                        memset(pass1, 0, strlen(pass1));
+                        free(pass1);
                         return -1;
+                }
 
                 ret = strcmp(pass1, pass2);
                 memset(pass2, 0, strlen(pass2));
@@ -1898,7 +1935,7 @@ typedef struct {
 
 static void print_info(const char *info, unsigned int pad)
 {
-        int i;
+        unsigned int i;
         size_t len = strlen(info);
 
         printf("%s", info);
@@ -1934,7 +1971,7 @@ static void print_add(unsigned int sub, const char *name, const char *uid, const
 
 static void print_added(void)
 {
-        int i;
+        unsigned int i;
         print_entry_t *ent;
         prelude_list_t *tmp, *bkp;
         unsigned int mtotal = 0, mpartial = 0;
@@ -2013,8 +2050,8 @@ static int list_cmd(int argc, char **argv)
 #endif
         gnutls_datum data;
         prelude_string_t *str;
-        unsigned int cert_max;
-        int ret, i, permission;
+        unsigned int cert_max, i;
+        int ret,  permission;
         gnutls_x509_crt certs[1024];
         char dirname[PATH_MAX];
         char buf[1024], analyzerid[128], uidbuf[128] = { 0 }, gidbuf[128] = { 0 };
@@ -2145,7 +2182,7 @@ static const struct cmdtbl tbl[] = {
 
 static int print_help(void)
 {
-        int i;
+        unsigned int i;
 
         fprintf(stderr, "\nUsage %s <subcommand> [options] [args]\n", myprogname);
         fprintf(stderr, "Type \"%s <subcommand>\" for help on a specific subcommand.\n\n", myprogname);
@@ -2160,7 +2197,7 @@ static int print_help(void)
 
 static int print_detailed_help(prelude_option_t *opt, const char *optarg, prelude_string_t *err, void *context)
 {
-        int i;
+        unsigned int i;
 
         for ( i = 0; i < sizeof(tbl) / sizeof(*tbl); i++ ) {
                 if ( strcmp(arg_command, tbl[i].cmd) == 0 ) {
@@ -2176,7 +2213,8 @@ static int print_detailed_help(prelude_option_t *opt, const char *optarg, prelud
 
 int main(int argc, char **argv)
 {
-        int i, ret = -1;
+        int ret = -1;
+        unsigned int i;
         const char *slash;
 
         slash = strrchr(argv[0], '/');
