@@ -351,7 +351,7 @@ int _prelude_get_file_name_and_path(const char *str, char **name, char **path)
                         needsep = (_prelude_init_cwd[cwdlen - 1] != '/' ) ? '/' : '\0';
 
                 ret = snprintf(pathname, sizeof(pathname), "%s%c", _prelude_init_cwd, needsep);
-                if ( ret < 0 || ret >= sizeof(pathname) )
+                if ( ret < 0 || (size_t) ret >= sizeof(pathname) )
                         return prelude_error_from_errno(errno);
         }
 
@@ -508,13 +508,13 @@ prelude_msg_priority_t _idmef_impact_severity_to_msg_priority(idmef_impact_sever
 {
         static const prelude_msg_priority_t priority[] = {
                 PRELUDE_MSG_PRIORITY_NONE, /* not bound                         */
-                PRELUDE_MSG_PRIORITY_LOW,  /* IDMEF_IMPACT_SEVERITY_LOW    -> 1 */
-                PRELUDE_MSG_PRIORITY_MID,  /* IDMEF_IMPACT_SEVERITY_MEDIUM -> 2 */
-                PRELUDE_MSG_PRIORITY_HIGH, /* IDMEF_IMPACT_SEVERITY_HIGH   -> 3 */
-                PRELUDE_MSG_PRIORITY_LOW   /* IDMEF_IMPACT_SEVERITY_INFO   -> 4 */
+                PRELUDE_MSG_PRIORITY_LOW,  /* IDMEF_IMPACT_SEVERITY_INFO   -> 1 */
+                PRELUDE_MSG_PRIORITY_LOW,  /* IDMEF_IMPACT_SEVERITY_LOW    -> 2 */
+                PRELUDE_MSG_PRIORITY_MID,  /* IDMEF_IMPACT_SEVERITY_MEDIUM -> 3 */
+                PRELUDE_MSG_PRIORITY_HIGH, /* IDMEF_IMPACT_SEVERITY_HIGH   -> 4 */
         };
 
-        if ( severity >= (sizeof(priority) / sizeof(*priority)) )
+        if ( severity < 0 || (size_t) severity >= (sizeof(priority) / sizeof(*priority)) )
                 return PRELUDE_MSG_PRIORITY_NONE;
 
         return priority[severity];
