@@ -66,12 +66,10 @@ static int get_absolute_filename(const char *lockfile)
 }
 
 
-
-
 static int lockfile_get_exclusive(const char *lockfile)
 {
         int fd;
-#ifndef WIN32
+#if !((defined _WIN32 || defined __WIN32__) && !defined __CYGWIN__)
         int ret;
         struct flock lock;
 #endif
@@ -80,7 +78,7 @@ static int lockfile_get_exclusive(const char *lockfile)
         if ( fd < 0 )
                 return prelude_error_from_errno(errno);
 
-#ifndef WIN32
+#if !((defined _WIN32 || defined __WIN32__) && !defined __CYGWIN__)
         fcntl(fd, F_SETFD, fcntl(fd, F_GETFD) | FD_CLOEXEC);
 
         lock.l_type = F_WRLCK;    /* write lock */
@@ -134,7 +132,6 @@ static int lockfile_write_pid(int fd, pid_t pid)
 
 
 
-
 /**
  * prelude_daemonize:
  * @lockfile: Filename to a lockfile.
@@ -149,7 +146,7 @@ static int lockfile_write_pid(int fd, pid_t pid)
 int prelude_daemonize(const char *lockfile)
 {
         pid_t pid;
-        int fd = 0, ret;
+        int fd = 0, ret, i;
 
         if ( lockfile ) {
                 ret = get_absolute_filename(lockfile);
@@ -157,16 +154,9 @@ int prelude_daemonize(const char *lockfile)
                         return ret;
         }
 
-#ifdef WIN32
+#if (defined _WIN32 || defined __WIN32__) && !defined __CYGWIN__
         prelude_log(PRELUDE_LOG_ERR, "Daemonize call unsupported in this environment.\n");
-
-        if ( lockfile ) {
-                pid = getpid();
-
-                ret = lockfile_write_pid(fd, pid);
-                if ( ret < 0 )
-                        return ret;
-        }
+        pid = getpid();
 #else
         pid = fork();
         if ( pid < 0 )
@@ -174,6 +164,7 @@ int prelude_daemonize(const char *lockfile)
 
         else if ( pid )
                 _exit(0);
+#endif
 
         if ( lockfile ) {
                 fd = lockfile_get_exclusive(slockfile);
@@ -185,6 +176,7 @@ int prelude_daemonize(const char *lockfile)
                         return ret;
         }
 
+#if !((defined _WIN32 || defined __WIN32__) && !defined __CYGWIN__)
         setsid();
 
         ret = chdir("/");
@@ -193,9 +185,20 @@ int prelude_daemonize(const char *lockfile)
 
         umask(0);
 
-        fclose(stdin);
-        fclose(stdout);
-        fclose(stderr);
+        fd = open("/dev/null", O_RDWR);
+        if ( fd < 0 )
+                return prelude_error_from_errno(errno);
+
+        for ( i = 0; i <= 2; i++ ) {
+                do {
+                        ret = dup2(fd, i);
+                } while ( ret < 0 && errno == EINTR );
+
+                if ( ret < 0 )
+                        return prelude_error_from_errno(errno);
+        }
+
+        close(fd);
 #endif
 
         return 0;
