@@ -30,6 +30,19 @@
  extern "C" {
 #endif
 
+#ifndef __attribute__
+/* This feature is available in gcc versions 2.5 and later.  */
+# if __GNUC__ < 2 || (__GNUC__ == 2 && __GNUC_MINOR__ < 5) || __STRICT_ANSI__
+#  define __attribute__(Spec) /* empty */
+# endif
+/* The __-protected variants of `format' and `printf' attributes
+   are accepted by gcc versions 2.6.4 (effectively 2.7) and later.  */
+# if __GNUC__ < 2 || (__GNUC__ == 2 && __GNUC_MINOR__ < 7)
+#  define __format__ format
+#  define __printf__ printf
+# endif
+#endif
+
 #ifdef HAVE_CONFIG_H
 # include "config.h"
 #endif
@@ -44,21 +57,25 @@ int idmef_path_get(const idmef_path_t *path, idmef_message_t *message, idmef_val
 
 int idmef_path_set(const idmef_path_t *path, idmef_message_t *message, idmef_value_t *value);
 
-int idmef_path_new(idmef_path_t **path, const char *format, ...);
-int idmef_path_new_v(idmef_path_t **path, const char *format, va_list args);
+int idmef_path_new(idmef_path_t **path, const char *format, ...)
+                   __attribute__ ((__format__ (__printf__, 2, 3)));
+
+int idmef_path_new_v(idmef_path_t **path, const char *format, va_list args)
+                     __attribute__ ((__format__ (__printf__, 2, 0)));
+
 int idmef_path_new_fast(idmef_path_t **path, const char *buffer);
 
 idmef_class_id_t idmef_path_get_class(const idmef_path_t *path, int depth);
 
 idmef_value_type_id_t idmef_path_get_value_type(const idmef_path_t *path, int depth);
 
-int idmef_path_set_index(idmef_path_t *path, unsigned int depth, unsigned int index);
+int idmef_path_set_index(idmef_path_t *path, unsigned int depth, int index);
 
 int idmef_path_undefine_index(idmef_path_t *path, unsigned int depth);
 
 int idmef_path_get_index(const idmef_path_t *path, unsigned int depth);
 
-int idmef_path_make_child(idmef_path_t *path, const char *child_name, unsigned int index);
+int idmef_path_make_child(idmef_path_t *path, const char *child_name, int index);
 
 int idmef_path_make_parent(idmef_path_t *path);
 
@@ -74,15 +91,19 @@ idmef_path_t *idmef_path_ref(idmef_path_t *path);
 
 const char *idmef_path_get_name(const idmef_path_t *path, int depth);
 
-prelude_bool_t idmef_path_is_ambiguous(idmef_path_t *path);
+prelude_bool_t idmef_path_is_ambiguous(const idmef_path_t *path);
 
-int idmef_path_has_lists(idmef_path_t *path);
+int idmef_path_has_lists(const idmef_path_t *path);
+
+prelude_bool_t idmef_path_is_list(const idmef_path_t *path, int depth);
 
-prelude_bool_t idmef_path_is_list(idmef_path_t *path, int depth);
-         
 unsigned int idmef_path_get_depth(const idmef_path_t *path);
 
-#ifndef SWIG         
+int idmef_path_check_operator(const idmef_path_t *path, idmef_criterion_operator_t op);
+
+int idmef_path_get_applicable_operators(const idmef_path_t *path, idmef_criterion_operator_t *result);
+
+#ifndef SWIG
 void _idmef_path_cache_lock(void);
 
 void _idmef_path_cache_reinit(void);
@@ -95,5 +116,5 @@ void _idmef_path_cache_destroy(void);
 #ifdef __cplusplus
  }
 #endif
-         
+
 #endif /* _LIBPRELUDE_IDMEF_PATH_H */
