@@ -107,7 +107,9 @@ int idmef_value_type_clone(const idmef_value_type_t *src, idmef_value_type_t *ds
 int idmef_value_type_compare(const idmef_value_type_t *type1, const idmef_value_type_t *type2,
                              idmef_criterion_operator_t op);
 
-int idmef_value_type_check_operator(const idmef_value_type_t *type, idmef_criterion_operator_t op);
+int idmef_value_type_check_operator(idmef_value_type_id_t type, idmef_criterion_operator_t op);
+
+int idmef_value_type_get_applicable_operators(idmef_value_type_id_t type, idmef_criterion_operator_t *result);
 
 const char *idmef_value_type_to_string(idmef_value_type_id_t type);
 
